==> strigi_0.3.8.orig.tar.gz: strigi-0.3.8.orig/src/searchclient/searchview.h <==
/* This file is part of Strigi Desktop Search
 *
 * Copyright (C) 2006 Jos van den Oever <jos@vandenoever.info>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef SEARCHVIEW_H
#define SEARCHVIEW_H

#include <QtGui/QWidget>
#include "qt4strigiclient.h"

class QTextBrowser;
class QUrl;
class SearchViewHtmlHelper;
class StrigiHtmlGui;

class SearchView : public QWidget {
Q_OBJECT
private:
    QTextBrowser* view;
    QString query;
    Qt4StrigiClient& strigi;
    SearchViewHtmlHelper* htmlguihelper;
    StrigiHtmlGui* htmlgui;

private slots:
    void openItem(const QUrl& url);
public:
    explicit SearchView(Qt4StrigiClient& k);
    ~SearchView();
    void setHTML(const QString&html);
public slots:
    void handleHits(const QString&, const ClientInterface::Hits&);
    void setQuery(const QString&);
};

#endif

==> strigi_0.3.9.orig.tar.gz: strigi-0.3.9.orig/src/searchclient/searchview.h <==
/* This file is part of Strigi Desktop Search
 *
 * Copyright (C) 2006 Jos van den Oever <jos@vandenoever.info>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#ifndef SEARCHVIEW_H
#define SEARCHVIEW_H

#include <QtGui/QWidget>
#include "qt4strigiclient.h"

class Qt4StrigiClient;
class QTextBrowser;
class QUrl;
class SearchViewHtmlHelper;
class StrigiHtmlGui;

class SearchView : public QWidget {
Q_OBJECT
private:
    QTextBrowser* view;
    QString query;
    Qt4StrigiClient* strigi;
    SearchViewHtmlHelper* htmlguihelper;
    StrigiHtmlGui* htmlgui;

private slots:
    void openItem(const QUrl& url);
public:
    explicit SearchView(Qt4StrigiClient* k);
    ~SearchView();
    void setHTML(const QString&html);
public slots:
    void handleHits(const QString&, const ClientInterface::Hits&);
    void setQuery(const QString&);
};

#endif
